@@ -2,6 +2,6 @@ from ._choice import Choice as Choice
 from .list import ListPrompt as ListPrompt
 from ._base import BasePrompt as BasePrompt
 from .input import InputPrompt as InputPrompt
-from ._base import CanceledError as CanceledError
+from ._base import CancelledError as CancelledError
 from .confirm import ConfirmPrompt as ConfirmPrompt
 from .checkbox import CheckboxPrompt as CheckboxPrompt
