@@ -1,5 +1,5 @@
 import abc
-from typing import Union, Generic, TypeVar, Optional
+from typing import Union, Generic, TypeVar, Optional, overload
 
 from prompt_toolkit.layout import Layout
 from prompt_toolkit.application import Application
@@ -13,6 +13,17 @@ RT = TypeVar("RT")
 NO_ANSWER = ...
 
 
+class UndefinedType:
+    def __str__(self):
+        return "Undefined"
+
+    def __bool__(self):
+        return False
+
+
+UNDEFINED = UndefinedType()
+
+
 class CancelledError(Exception):
     """User cancelled answer."""
 
@@ -49,9 +60,27 @@ class BasePrompt(abc.ABC, Generic[RT]):
             mouse_support=True,
         )
 
+    @overload
     def prompt(
         self,
-        default: DT = None,
+        default: UndefinedType = UNDEFINED,
+        no_ansi: bool = False,
+        style: Optional[Style] = None,
+    ) -> RT:
+        ...
+
+    @overload
+    def prompt(
+        self,
+        default: DT,
+        no_ansi: bool = False,
+        style: Optional[Style] = None,
+    ) -> Union[DT, RT]:
+        ...
+
+    def prompt(
+        self,
+        default: Union[DT, UndefinedType] = UNDEFINED,
         no_ansi: bool = False,
         style: Optional[Style] = None,
     ) -> Union[DT, RT]:
@@ -59,6 +88,6 @@ class BasePrompt(abc.ABC, Generic[RT]):
         result: RT = app.run()
         if result is not NO_ANSWER:
             return result
-        if default is None:
+        if default is UNDEFINED:
             raise CancelledError("No answer selected!")
         return default
