@@ -1,4 +1,5 @@
 import os
+from time import time
 from functools import lru_cache
 from typing import List, TypeVar, Callable, Optional
 
@@ -7,6 +8,7 @@ from prompt_toolkit.buffer import Buffer
 from prompt_toolkit.layout import Layout
 from prompt_toolkit.filters import is_done
 from prompt_toolkit.lexers import SimpleLexer
+from prompt_toolkit.application import get_app
 from prompt_toolkit.enums import DEFAULT_BUFFER
 from prompt_toolkit.layout.dimension import Dimension
 from prompt_toolkit.formatted_text import AnyFormattedText
@@ -66,13 +68,20 @@ class ListPrompt(BasePrompt[Choice[RT]]):
         self._display_index: int = 0
         self._max_height: Optional[int] = max_height
 
+        self._last_mouse_up: float = 0
+        self._last_mouse_index: int = 0
+
     @property
     def max_height(self) -> int:
         return self._max_height or os.get_terminal_size().lines
 
     @property
     def filtered_choices(self) -> List[Choice[RT]]:
-        return [choice for choice in self.choices if self._buffer.text in choice.name]
+        return [
+            choice
+            for choice in self.choices
+            if self._buffer.text.lower() in choice.name.lower()
+        ]
 
     def _reset(self):
         self._answered: Optional[Choice] = None
@@ -126,7 +135,7 @@ class ListPrompt(BasePrompt[Choice[RT]]):
     def _build_style(self, style: Style) -> Style:
         default = Style(
             [
-                ("questionmark", "fg:#5F819D"),
+                ("questionmark", "fg:#673AB7 bold"),
                 ("question", "bold"),
                 ("answer", "fg:#FF9D00"),
                 ("annotation", "fg:#7F8C8D"),
@@ -148,16 +157,7 @@ class ListPrompt(BasePrompt[Choice[RT]]):
 
         @kb.add("enter", eager=True)
         def enter(event: KeyPressEvent):
-            # no answer selected
-            if not self.filtered_choices:
-                return
-
-            # get result first
-            result = self.filtered_choices[self._index]
-            self._answered = result
-            # then clear buffer
-            self._buffer.reset()
-            event.app.exit(result=result)
+            self._finish()
 
         @kb.add("c-c", eager=True)
         @kb.add("c-q", eager=True)
@@ -166,6 +166,18 @@ class ListPrompt(BasePrompt[Choice[RT]]):
 
         return kb
 
+    def _finish(self) -> None:
+        # no answer selected
+        if not self.filtered_choices:
+            return
+
+        # get result first
+        result = self.filtered_choices[self._index]
+        self._answered = result
+        # then clear buffer
+        self._buffer.reset()
+        get_app().exit(result=result)
+
     def _get_line_prefix(self, line_number: int, wrap_count: int) -> AnyFormattedText:
         return self._get_prompt()
 
@@ -232,6 +244,13 @@ class ListPrompt(BasePrompt[Choice[RT]]):
         def _handle_mouse(event: MouseEvent) -> None:
             if event.event_type == MouseEventType.MOUSE_UP and index is not None:
                 self._jump_to(index)
+                if (
+                    time() - self._last_mouse_up
+                ) < 0.3 and index == self._last_mouse_index:
+                    self._finish()
+                else:
+                    self._last_mouse_up = time()
+                    self._last_mouse_index = index
             elif event.event_type == MouseEventType.SCROLL_UP:
                 self._handle_up()
             elif event.event_type == MouseEventType.SCROLL_DOWN:
